## ----chunk_setup, include = FALSE---------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----vignette_setup, echo=FALSE, message=FALSE, warning = FALSE---------------
# Track time spent on making the vignette.
start_time <- Sys.time()

# Bib setup.
library(RefManageR)

# Write bibliography information
bib <- c(
    R = citation(),
    BiocStyle = citation("BiocStyle")[1],
    knitr = citation("knitr")[1],
    rmarkdown = citation("rmarkdown")[1],
    sessioninfo = citation("sessioninfo")[1],
    testthat = citation("testthat")[1],
    RefManageR = citation("RefManageR")[1],
    decoupleR = citation("decoupleR")[1],
    GSVA = citation("GSVA")[1],
    viper = citation("viper")[1]
)

## ----bioconductor_install, eval=FALSE-----------------------------------------
#  if (!requireNamespace("BiocManager", quietly = TRUE)) {
#      install.packages("BiocManager")
#  }
#  
#  BiocManager::install("decoupleR")
#  
#  # Check that you have a valid Bioconductor installation
#  BiocManager::valid()

## ----github_install, eval=FALSE-----------------------------------------------
#  BiocManager::install("saezlab/decoupleR")

## ----decoupleR citation-------------------------------------------------------
citation("decoupleR")

## ----load_library, message=FALSE----------------------------------------------
library(decoupleR)
library(dplyr)

## ----read_example_data--------------------------------------------------------
inputs_dir <- system.file("testdata", "inputs", package = "decoupleR")

mat <- file.path(inputs_dir, "input-expr_matrix.rds") %>%
    readRDS() %>%
    glimpse()

network <- file.path(inputs_dir, "input-dorothea_genesets.rds") %>%
    readRDS() %>%
    glimpse()

# We recommend to intersect and set a minsize of targets
network <- intersect_regulons(mat, network, tf, target, minsize=5)

## ----usage-decouple_function, message=TRUE------------------------------------
decouple(
    mat = mat,
    network = network,
    .source = "tf",
    .target = "target",
    statistics = c("gsva", "wmean", "mlm", "ora"),
    args = list(
        gsva = list(verbose = FALSE),
        wmean = list(times = 100),
        mlm = list(center=FALSE),
        ora = list(n_up=300, n_bottom=300, n_background=20000)
    )
) %>%
    glimpse()

## ----see only_stats-----------------------------------------------------------
only_stats <- decouple(
    mat = head(mat, 5000),
    network = network,
    .source = "tf",
    .target = "target",
    statistics = c("ora", "ulm", "gsva"),
    consensus_score = FALSE,
    show_toy_call = TRUE
)

## ----in_args------------------------------------------------------------------
add_args <- decouple(
    mat = head(mat, 5000),
    network = network,
    .source = "tf",
    .target = "target",
    statistics = c('gsva', 'ora', 'ulm'),
    args = list(
        ora = list(n_up=300, n_bottom=300, n_background=20000),
        ulm = list(center = F)
    ),
    consensus_score = FALSE,
    show_toy_call = TRUE
)

## ----see_not_differences------------------------------------------------------
all.equal(only_stats, add_args)

## ----show_columns-------------------------------------------------------------
network %>%
    colnames()

## -----------------------------------------------------------------------------
this_column <- "target"
viper_res <- decouple(
    mat = mat,
    network = network,
    .source = tf,
    .target = !!this_column,
    statistics = c("viper"),
    args = list(
        viper = list(
            .mor = 4,
            .likelihood = "likelihood",
            verbose = FALSE
        )
    ),
    show_toy_call = TRUE
)

## ----create_vignette, eval=FALSE----------------------------------------------
#  # Create the vignette
#  library(rmarkdown)
#  system.time(render("decoupleR.Rmd", "BiocStyle::html_document"))
#  
#  # Extract the R code
#  library(knitr)
#  knit("decoupleR.Rmd", tangle = TRUE)

## ----reproduce_time, echo=FALSE-----------------------------------------------
# Processing time in seconds
total_time <- diff(c(start_time, Sys.time()))
round(total_time, digits = 3)

## ----session_info, echo=FALSE-----------------------------------------------------------------------------------------
options(width = 120)
sessioninfo::session_info()

## ----vignetteBiblio, results = "asis", echo = FALSE, warning = FALSE, message = FALSE---------------------------------
## Print bibliography
PrintBibliography(bib, .opts = list(hyperlink = "to.doc", style = "html"))

